;; Generated package description from vertico-posframe.el  -*- no-byte-compile: t -*-
(define-package "vertico-posframe" "0.9.2.0.20260201.41512" "Using posframe to show Vertico" '((emacs "26.0") (posframe "1.4.0") (vertico "2.6")) :commit "d6e06a4f1b34d24cc0ca6ec69d2d6c965191b23e" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("abbrev" "convenience" "matching" "vertico") :url "https://github.com/tumashu/vertico-posframe")
